function eit_good_data, data , badcount, ss=ss, $
   nrows=nrows, max_expected=max_expected, debug=debug
;
;+
;   Name: eit_good_data
;
;   Purpose: empirically derived quality (filter bad reformatted images)
;
;   Input Parameters:
;      data - the data array (read_eit output for example), 2D or 3D
;
;   Output:
;      function returns boolean; length=number of images; 1=ok, 0=bad
;      optionally, return subscrits of good images if /SS set
;
;   Output Parameters:
;      badcount - number of images which failed filter
;
;   Keyword Parameters:
;      nrows - number of rows to consider ; default = 1 row (row 0)
;      max_expected - largest deviation expected column to column (def=50)
;      
;

if n_elements(expected) eq 0 then expected=50 ; max expected column deriv 

debug=keyword_set(debug)
if n_elements(nrows) eq 0 then nrows=1
nimages=data_chk(data,/nimag)

ctot=total(data(*,0:(nrows>0),*),2)

darr=fltarr(data_chk(data,/nx),nimages)
retval=intarr(nimages)                     

for i=0,nimages-1 do begin 
   dcols=deriv_arr(ctot(*,i))
   dcols_norm=dcols/nrows
   ssbad=where(abs(dcols_norm) gt expected,bcnt)
   if debug then stop,bcnt 
   retval(i)=bcnt le 4 
endfor

ss=where(1-retval,badcount)                 ; output #bad

return,retval
end
